==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebRowSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDetailDescription } from "./WebRowSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowSelectionEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRowSelectionEventArgsDetailDescriptionMetadata, _super);
    function WebRowSelectionEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectionEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowSelectionEventArgsDetailDescriptionMetadata.a == null) {
            WebRowSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectionEventArgsDetailDescriptionMetadata.c(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebRowSelectionEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebRowSelectionEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowSelectionEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("OldSelectionRef", "(w:OldSelection,wf:OldSelection)DataRef:object");
        a.item("NewSelectionRef", "(w:NewSelection,wf:NewSelection)DataRef:object");
        a.item("AddedRef", "(w:Added,wf:Added)DataRef:object");
        a.item("RemovedRef", "(w:Removed,wf:Removed)DataRef:object");
    };
    WebRowSelectionEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowSelectionEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebRowSelectionEventArgsDetail", function () { return new WebRowSelectionEventArgsDetailDescription(); });
        a.z("WebRowSelectionEventArgsDetail", WebRowSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebRowSelectionEventArgsDetailDescriptionMetadata.$t = markType(WebRowSelectionEventArgsDetailDescriptionMetadata, 'WebRowSelectionEventArgsDetailDescriptionMetadata');
    WebRowSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowSelectionEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebRowSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDetailDescription } from "./WebRowSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowSelectionEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRowSelectionEventArgsDetailDescriptionMetadata, _super);
    function WebRowSelectionEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowSelectionEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowSelectionEventArgsDetailDescriptionMetadata.a == null) {
            WebRowSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowSelectionEventArgsDetailDescriptionMetadata.c(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebRowSelectionEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebRowSelectionEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowSelectionEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("OldSelectionRef", "(w:OldSelection,wf:OldSelection)DataRef:object");
        a.item("NewSelectionRef", "(w:NewSelection,wf:NewSelection)DataRef:object");
        a.item("AddedRef", "(w:Added,wf:Added)DataRef:object");
        a.item("RemovedRef", "(w:Removed,wf:Removed)DataRef:object");
        a.item("AllRowsSelected", "Boolean");
    };
    WebRowSelectionEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowSelectionEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebRowSelectionEventArgsDetail", function () { return new WebRowSelectionEventArgsDetailDescription(); });
        a.ab("WebRowSelectionEventArgsDetail", WebRowSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebRowSelectionEventArgsDetailDescriptionMetadata.$t = markType(WebRowSelectionEventArgsDetailDescriptionMetadata, 'WebRowSelectionEventArgsDetailDescriptionMetadata');
    WebRowSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowSelectionEventArgsDetailDescriptionMetadata };
